agentle.agents.whatsapp.models.whatsapp\_bot\_config
====================================================

.. automodule:: agentle.agents.whatsapp.models.whatsapp_bot_config

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      BaseModel
      WhatsAppBotConfig
   